
from loguru import logger
import pandas as pd


from cleancourt.check_spaces import *
from cleancourt.clean_data import *
from cleancourt.cosine_similarity import *
from cleancourt.integrate_output import *
from cleancourt.parse_names import *


def full_clean_names(messy_names):
    
    df = pd.DataFrame()

    df['clean_names_1'] = [clean_data(x) for x in tqdm(messy_names)]



    # Parse the people names and format
    logger.info("PARSING PEOPLE NAMES")
    duplicates_dict_people = format_people_names(df['clean_names_1'])

    # Merge names into df
    logger.info("MERGING PEOPLE NAMES")
    df['formatted_people_names'] = df.apply(lambda x: map_values(x.clean_names_1, duplicates_dict_people), axis=1)

    # Parse company names
    logger.info("PARSING COMPANY NAMES")
    duplicates_dict_company = link_company_names(df['clean_names_1'])

    # Merge company names into df
    logger.info("MERGING COMPANY NAMES")
    df['formatted_company_names'] = df.apply(lambda x: map_values(x.clean_names_1, duplicates_dict_company), axis=1)

    # Create column of all company and people names
    logger.info("ADDING ALL NAMES TO DF")
    df['clean_names_2'] = df.apply(lambda x: combine_columns(x.clean_names_1, x.formatted_people_names, x.formatted_company_names), axis=1)

    # Check for erroneous spaces that may prevent names from being matched
    logger.info("CHECKING SPACES")
    duplicates_dict_spaces = check_spaces(df['clean_names_2'])

    # add values returned from no spaces to df
    logger.info("ADDING NO SPACES NAMES TO DF")
    df['clean_names_3'] = df.apply(lambda x: map_values(x.clean_names_2, duplicates_dict_spaces), axis=1)

    # Combine all cleaned names columns into one column for use
    df['clean_name_final'] = df.apply(lambda x: combine_columns_no_space(x.clean_names_2, x.clean_names_3), axis=1)

    return(df['clean_name_final'])